@@ -37,29 +37,29 @@ public:
   CubicImp( const CubicCartesianData& data );
   ~CubicImp();
 
-  ObjectImp* transform( const Transformation& ) const;
-  void draw( KigPainter& p ) const;
-  bool contains( const Coordinate& p, int width, const KigWidget& ) const;
-  bool inRect( const Rect& r, int width, const KigWidget& ) const;
-  Rect surroundingRect() const;
+  ObjectImp* transform( const Transformation& ) const Q_DECL_OVERRIDE;
+  void draw( KigPainter& p ) const Q_DECL_OVERRIDE;
+  bool contains( const Coordinate& p, int width, const KigWidget& ) const Q_DECL_OVERRIDE;
+  bool inRect( const Rect& r, int width, const KigWidget& ) const Q_DECL_OVERRIDE;
+  Rect surroundingRect() const Q_DECL_OVERRIDE;
   QString cartesianEquationString( const KigDocument& ) const;
 
-  int numberOfProperties() const;
-  const QByteArrayList properties() const;
-  const QByteArrayList propertiesInternalNames() const;
-  ObjectImp* property( int which, const KigDocument& w ) const;
-  const char* iconForProperty( int which ) const;
-  const ObjectImpType* impRequirementForProperty( int which ) const;
-  bool isPropertyDefinedOnOrThroughThisImp( int which ) const;
+  int numberOfProperties() const Q_DECL_OVERRIDE;
+  const QByteArrayList properties() const Q_DECL_OVERRIDE;
+  const QByteArrayList propertiesInternalNames() const Q_DECL_OVERRIDE;
+  ObjectImp* property( int which, const KigDocument& w ) const Q_DECL_OVERRIDE;
+  const char* iconForProperty( int which ) const Q_DECL_OVERRIDE;
+  const ObjectImpType* impRequirementForProperty( int which ) const Q_DECL_OVERRIDE;
+  bool isPropertyDefinedOnOrThroughThisImp( int which ) const Q_DECL_OVERRIDE;
 
-  CubicImp* copy() const;
+  CubicImp* copy() const Q_DECL_OVERRIDE;
 
-  double getParam( const Coordinate& point, const KigDocument& ) const;
+  double getParam( const Coordinate& point, const KigDocument& ) const Q_DECL_OVERRIDE;
 
   // The getPoint function doesn't need the KigDocument argument, the
   // first getPoint function is identical to the other one.  It is
   // only provided for implementing the CurveImp interface.
-  const Coordinate getPoint( double param, const KigDocument& ) const;
+  const Coordinate getPoint( double param, const KigDocument& ) const Q_DECL_OVERRIDE;
   const Coordinate getPoint( double param ) const;
 
 public:
@@ -68,12 +68,12 @@ public:
    */
   const CubicCartesianData data() const;
 
-  const ObjectImpType* type() const;
-  void visit( ObjectImpVisitor* vtor ) const;
+  const ObjectImpType* type() const Q_DECL_OVERRIDE;
+  void visit( ObjectImpVisitor* vtor ) const Q_DECL_OVERRIDE;
 
-  bool equals( const ObjectImp& rhs ) const;
+  bool equals( const ObjectImp& rhs ) const Q_DECL_OVERRIDE;
 
-  bool containsPoint( const Coordinate& p, const KigDocument& doc ) const;
+  bool containsPoint( const Coordinate& p, const KigDocument& doc ) const Q_DECL_OVERRIDE;
   bool internalContainsPoint( const Coordinate& p, double threshold ) const;
   bool isVerticalCubic() const;
 };
